@@ -43,7 +43,7 @@ int WindowsPoller::getIdleTime()
 bool WindowsPoller::additionalSetUp()
 {
     m_idleTimer = new QTimer(this);
-    connect(m_idleTimer, SIGNAL(timeout()), this, SLOT(checkForIdle()));
+    connect(m_idleTimer, &QTimer::timeout, this, &WindowsPoller::checkForIdle);
     return true;
 }
 
@@ -72,7 +72,6 @@ void WindowsPoller::checkForIdle()
 {
     if (getIdleTime() < 1000) {
         stopCatchingIdleEvents();
-        emit resumingFromIdle();
+        Q_EMIT resumingFromIdle();
     }
 }
-
